@@ -1,5 +1,6 @@
 
 import asyncio
+from aiohttp import web
 import uuid
 
 from . config import ConfigRequestor
@@ -30,6 +31,9 @@ from . graph_embeddings_import import GraphEmbeddingsImport
 from . document_embeddings_import import DocumentEmbeddingsImport
 from . entity_contexts_import import EntityContextsImport
 
+from . core_export import CoreExport
+from . core_import import CoreImport
+
 from . mux import Mux
 
 request_response_dispatchers = {
@@ -77,10 +81,11 @@ class DispatcherWrapper:
 
 class DispatcherManager:
 
-    def __init__(self, pulsar_client, config_receiver):
+    def __init__(self, pulsar_client, config_receiver, prefix="api-gateway"):
         self.pulsar_client = pulsar_client
         self.config_receiver = config_receiver
         self.config_receiver.add_handler(self)
+        self.prefix = prefix
 
         self.flows = {}
         self.dispatchers = {}
@@ -98,6 +103,22 @@ class DispatcherManager:
     def dispatch_global_service(self):
         return DispatcherWrapper(self.process_global_service)
 
+    def dispatch_core_export(self):
+        return DispatcherWrapper(self.process_core_export)
+
+    def dispatch_core_import(self):
+        return DispatcherWrapper(self.process_core_import)
+
+    async def process_core_import(self, data, error, ok, request):
+
+        ci = CoreImport(self.pulsar_client)
+        return await ci.process(data, error, ok, request)
+
+    async def process_core_export(self, data, error, ok, request):
+
+        ce = CoreExport(self.pulsar_client)
+        return await ce.process(data, error, ok, request)
+
     async def process_global_service(self, data, responder, params):
 
         kind = params.get("kind")
@@ -113,8 +134,8 @@ class DispatcherManager:
         dispatcher = global_dispatchers[kind](
             pulsar_client = self.pulsar_client,
             timeout = 120,
-            consumer = f"api-gateway-{kind}-request",
-            subscriber = f"api-gateway-{kind}-request",
+            consumer = f"{self.prefix}-{kind}-request",
+            subscriber = f"{self.prefix}-{kind}-request",
         )
 
         await dispatcher.start()
@@ -206,8 +227,8 @@ class DispatcherManager:
             ws = ws,
             running = running,
             queue = qconfig,
-            consumer = f"api-gateway-{id}",
-            subscriber = f"api-gateway-{id}",
+            consumer = f"{self.prefix}-{id}",
+            subscriber = f"{self.prefix}-{id}",
         )
 
         return dispatcher
@@ -248,8 +269,8 @@ class DispatcherManager:
                 request_queue = qconfig["request"],
                 response_queue = qconfig["response"],
                 timeout = 120,
-                consumer = f"api-gateway-{flow}-{kind}-request",
-                subscriber = f"api-gateway-{flow}-{kind}-request",
+                consumer = f"{self.prefix}-{flow}-{kind}-request",
+                subscriber = f"{self.prefix}-{flow}-{kind}-request",
             )
         elif kind in sender_dispatchers:
             dispatcher = sender_dispatchers[kind](
